Citing seglearn
===============

If you use seglearn in a scientific publication, we would appreciate
citations to the following paper::

  @article{arXiv:1803.08118,
  author  = {David Burns, Cari Whyne},
  title   = {Seglearn: A Python Package for Learning Sequences and Time Series},
  journal = {arXiv},
  year    = {2018},
  url     = {https://arxiv.org/abs/1803.08118}
  }


If you use the seglearn test data in a scientific publication, we would appreciate
citations to the following paper::

  @article{arXiv:1802.01489,
  author  = {David Burns, Nathan Leung, Michael Hardisty, Cari Whyne, Patrick Henry, Stewart McLachlin},
  title   = {Shoulder Physiotherapy Exercise Recognition: Machine Learning the Inertial Signals from a Smartwatch},
  journal = {arXiv},
  year    = {2018},
  url     = {https://arxiv.org/abs/1802.01489}
  }